@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Matthias Blaesing <matthias.blaesing@rwth-aachen.de>
+# Copyright © 2003 - 2018 Matthias Blaesing <matthias.blaesing@rwth-aachen.de>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -244,7 +244,7 @@ def main():
 
     # Check AddFolder
     print("\n\nExpection: Creation of a folder on the memorycard \"42alpha\"")
-    file_f = state_machine.AddFolder(unicode(args.folder), u"42alpha")
+    state_machine.AddFolder(unicode(args.folder), u"42alpha")
 
     # Check GetFolderListing again *wired*
     print("\n\nExpection: Print properties of newly created folder")
