@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -30,7 +30,7 @@ import sys
 state_machine = gammu.StateMachine()
 
 # Optionally load config file as defined by first parameter
-if len(sys.argv) >= 2:
+if len(sys.argv) > 2:
     # Read the configuration from given file
     state_machine.ReadConfig(Filename=sys.argv[1])
     # Remove file name from args list
