@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2017 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
 # This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
@@ -27,7 +27,7 @@ import sys
 
 state_machine = gammu.StateMachine()
 
-if len(sys.argv) >= 2:
+if len(sys.argv) > 2:
     state_machine.ReadConfig(Filename=sys.argv[1])
     del sys.argv[1]
 else:
