@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (C) 2003 - 2017 Michal Čihař
+ * Copyright (C) 2003 - 2018 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1387,6 +1387,11 @@ char *MultiPartSMSIDToString(EncodeMultiPartSMSID type)
 		case SMS_SiemensFile:
 			s = strdup("SiemensFile");
 			break;
+#if GAMMU_VERSION_NUM >= 13805
+		case SMS_USSD:
+			s = strdup("USSD");
+			break;
+#endif
 	}
 
 	if (s == NULL) {
